import { render, screen, waitFor } from '@testing-library/react'
import { UserChallengeState } from 'enums'
import { DateTime } from 'luxon'
import { UserChallenge } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import DuelOngoing from './DuelOngoing'

const mockUserChallengeUpdateFlag = jest.fn()
const mockIsChallengeDone = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: mockUserChallengeUpdateFlag,
    isChallengeDone: mockIsChallengeDone,
  }))
})

jest.mock('components/Duel/DuelChart/DuelChart', () => 'mock-duelchart')

describe('DuelOngoing component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', async () => {
    mockIsChallengeDone.mockReturnValue({
      isDone: false,
      isWin: false,
    })
    const { container } = render(
      <Provider store={store}>
        <DuelOngoing userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(container).toMatchSnapshot()
    expect(
      screen.getByText(userChallengeData[1].duel.title)
    ).toBeInTheDocument()
  })

  it('should display the result Modal when duel is done', async () => {
    const updatedUserChallenge: UserChallenge = {
      ...userChallengeData[0],
      state: UserChallengeState.DUEL,
      startDate: DateTime.local().setZone('utc', { keepLocalTime: true }),
    }
    mockIsChallengeDone.mockReturnValue({
      isDone: true,
      isWin: true,
    })
    mockUserChallengeUpdateFlag.mockResolvedValue(updatedUserChallenge)
    const { container } = render(
      <Provider store={store}>
        <DuelOngoing userChallenge={updatedUserChallenge} />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(screen.getByRole('dialog')).toBeInTheDocument()
  })
})
